[folded-merged] hotplug-update-nodemasks-management-fix.patch removed from -mm tree

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



The patch titled
     Subject: hotplug-update-nodemasks-management-fix
has been removed from the -mm tree.  Its filename was
     hotplug-update-nodemasks-management-fix.patch

This patch was dropped because it was folded into hotplug-update-nodemasks-management.patch

------------------------------------------------------
From: Bob Liu <lliubbo@xxxxxxxxx>
Subject: hotplug-update-nodemasks-management-fix

fix build

Signed-off-by: Bob Liu <lliubbo@xxxxxxxxx>
Cc: Christoph Lameter <cl@xxxxxxxxx>
Cc: David Rientjes <rientjes@xxxxxxxxxx>
Cc: Hillf Danton <dhillf@xxxxxxxxx>
Cc: Lai Jiangshan <laijs@xxxxxxxxxxxxxx>
Cc: Lin Feng <linfeng@xxxxxxxxxxxxxx>
Cc: Wen Congyang <wency@xxxxxxxxxxxxxx>
Signed-off-by: Andrew Morton <akpm@xxxxxxxxxxxxxxxxxxxx>
---

 mm/memory_hotplug.c |   14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

diff -puN mm/memory_hotplug.c~hotplug-update-nodemasks-management-fix mm/memory_hotplug.c
--- a/mm/memory_hotplug.c~hotplug-update-nodemasks-management-fix
+++ a/mm/memory_hotplug.c
@@ -620,14 +620,14 @@ static void node_states_check_changes_on
 #ifdef CONFIG_HIGHMEM
 	/*
 	 * If we have movable node, node_states[N_HIGH_MEMORY]
 	 * contains nodes which have zones of 0...ZONE_HIGH,
 	 * set zone_last to ZONE_HIGH.
 	 *
 	 * If we don't have movable node, node_states[N_NORMAL_MEMORY]
 	 * contains nodes which have zones of 0...ZONE_MOVABLE,
 	 * set zone_last to ZONE_MOVABLE.
 	 */
-	zone_last = ZONE_HIGH;
+	zone_last = ZONE_HIGHMEM;
 	if (N_MEMORY == N_HIGH_MEMORY)
 		zone_last = ZONE_MOVABLE;
 
@@ -1151,17 +1151,17 @@ static void node_states_check_changes_of
 	else
 		arg->status_change_nid_normal = -1;
 
-#ifdef CONIG_HIGHMEM
+#ifdef CONFIG_HIGHMEM
 	/*
 	 * If we have movable node, node_states[N_HIGH_MEMORY]
 	 * contains nodes which have zones of 0...ZONE_HIGH,
 	 * set zone_last to ZONE_HIGH.
 	 *
 	 * If we don't have movable node, node_states[N_NORMAL_MEMORY]
 	 * contains nodes which have zones of 0...ZONE_MOVABLE,
 	 * set zone_last to ZONE_MOVABLE.
 	 */
-	zone_last = ZONE_HIGH;
+	zone_last = ZONE_HIGHMEM;
 	if (N_MEMORY == N_HIGH_MEMORY)
 		zone_last = ZONE_MOVABLE;
 
@@ -620,14 +620,14 @@ static void node_states_check_changes_on
 	/*
 	 * If we have movable node, node_states[N_HIGH_MEMORY]
-	 * contains nodes which have zones of 0...ZONE_HIGH,
-	 * set zone_last to ZONE_HIGH.
+	 * contains nodes which have zones of 0...ZONE_HIGHMEM,
+	 * set zone_last to ZONE_HIGHMEM.
 	 *
 	 * If we don't have movable node, node_states[N_NORMAL_MEMORY]
@@ -1151,17 +1151,17 @@ static void node_states_check_changes_of
 	/*
 	 * If we have movable node, node_states[N_HIGH_MEMORY]
-	 * contains nodes which have zones of 0...ZONE_HIGH,
-	 * set zone_last to ZONE_HIGH.
+	 * contains nodes which have zones of 0...ZONE_HIGHMEM,
+	 * set zone_last to ZONE_HIGHMEM.
 	 *
 	 * If we don't have movable node, node_states[N_NORMAL_MEMORY]
_

Patches currently in -mm which might be from lliubbo@xxxxxxxxx are

origin.patch
thp-implement-refcounting-for-huge-zero-page.patch
thp-avoid-race-on-multiple-parallel-page-faults-to-the-same-page.patch
hotplug-update-nodemasks-management.patch

--
To unsubscribe from this list: send the line "unsubscribe mm-commits" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[Index of Archives]     [Kernel Newbies FAQ]     [Kernel Archive]     [IETF Annouce]     [DCCP]     [Netdev]     [Networking]     [Security]     [Bugtraq]     [Photo]     [Yosemite]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Linux SCSI]

  Powered by Linux